#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optparse-generic
version:              1.5.3
visibility:           public
id:                   optparse-generic-1.5.3-4DBgTEvhqO0CIFRIVkg3Y2
key:                  optparse-generic-1.5.3-4DBgTEvhqO0CIFRIVkg3Y2
license:              BSD-3-Clause
copyright:            2016 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Auto-generate a command-line parser for your datatype
description:
    This library auto-generates an @optparse-applicative@-compatible
    @Parser@ from any data type that derives the @Generic@ interface.

    See the documentation in "Options.Generic" for an example of how to use
    this library

category:             System
abi:                  559265bde280822626ead7a915bfcdbc
exposed:              True
exposed-modules:      Options.Generic
import-dirs:          /usr/lib/ghc-9.6.6/site-local/optparse-generic-1.5.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/optparse-generic-1.5.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/optparse-generic-1.5.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optparse-generic
hs-libraries:         HSoptparse-generic-1.5.3-4DBgTEvhqO0CIFRIVkg3Y2
depends:
    Only-0.1-DItEcvi68ww8z5TVixWVcj base-4.18.2.1 bytestring-0.11.5.3
    filepath-1.4.300.1
    optparse-applicative-0.18.1.0-D1qnF9ppDr4DKTCW01gXle text-2.0.2
    time-1.12.2 transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    void-0.7.4-Ab78HEYVlxC2PerDGXO6Wd

haddock-interfaces:
    /usr/share/doc/haskell-optparse-generic/html/optparse-generic.haddock

haddock-html:         /usr/share/doc/haskell-optparse-generic/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

